
import React, { Suspense, useEffect } from "react";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { HelmetProvider } from 'react-helmet-async';
import { AuthProvider } from "./contexts/AuthContext";
import { Toaster } from "sonner";
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import ScrollToTop from "./components/ScrollToTop";
import { useCoreWebVitals } from "./hooks/useCoreWebVitals";
import {
  LazyLanding,
  LazyIndex,
  LazyFeatures,
  LazyStatus,
  LazyDocumentation,
  LazyNotFound,
  LazyFAQ,
  LazyContact,
  LazyBugReports,
  LazyPrivacyPolicy,
  LazyTermsOfService,
  LazyGDPR,
  LazyCookiePolicy,
  LazyBlog,
  LazyBlogPost,
  preloadCriticalRoutes
} from "./utils/lazyRoutes";

// Lazy load admin dashboard
const LazyAdminDashboard = React.lazy(() => import("./pages/AdminDashboard"));

const queryClient = new QueryClient();

// Loading component for Suspense fallbacks
const PageLoader = () => (
  <div className="min-h-screen bg-gradient-to-br from-gray-900 via-black to-gray-900 flex items-center justify-center">
    <div className="text-center">
      <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-purple-500 mx-auto mb-4"></div>
      <p className="text-white/70">Loading...</p>
    </div>
  </div>
);

// Core Web Vitals reporting
const reportWebVitals = (metric: any) => {
  // In production, you could send this to analytics
  if (process.env.NODE_ENV === 'production') {
    // Example: analytics.track('web-vital', metric);
  }
};

// App component with Web Vitals monitoring
const AppWithVitals = () => {
  useCoreWebVitals(reportWebVitals);

  return (
    <HelmetProvider>
      <AuthProvider>
        <QueryClientProvider client={queryClient}>
          <Toaster />
          <BrowserRouter>
            <ScrollToTop />
            <Suspense fallback={<PageLoader />}>
              <Routes>
                <Route path="/" element={<LazyLanding />} />
                <Route path="/dashboard" element={<LazyIndex />} />
                <Route path="/admin" element={<LazyAdminDashboard />} />
                <Route path="/features" element={<LazyFeatures />} />
                <Route path="/status" element={<LazyStatus />} />
                <Route path="/documentation" element={<LazyDocumentation />} />
                <Route path="/faq" element={<LazyFAQ />} />
                <Route path="/contact" element={<LazyContact />} />
                <Route path="/bug-reports" element={<LazyBugReports />} />
                <Route path="/privacy-policy" element={<LazyPrivacyPolicy />} />
                <Route path="/terms-of-service" element={<LazyTermsOfService />} />
                <Route path="/cookie-policy" element={<LazyCookiePolicy />} />
                <Route path="/gdpr" element={<LazyGDPR />} />
                <Route path="/blog" element={<LazyBlog />} />
                <Route path="/blog/:slug" element={<LazyBlogPost />} />
                <Route path="*" element={<LazyNotFound />} />
              </Routes>
            </Suspense>
          </BrowserRouter>
        </QueryClientProvider>
      </AuthProvider>
    </HelmetProvider>
  );
};

// Preload critical routes on app initialization
React.startTransition(() => {
  preloadCriticalRoutes();
});

function App() {
  return <AppWithVitals />;
}

export default App;
